#
# spec file for package libcgroup
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define lname	libcgroup3
Name:           libcgroup
Version:        3.1.0
Release:        1.5
Summary:        Tools and libraries to control and monitor control groups
License:        LGPL-2.1-only
Url:            https://github.com/libcgroup/libcgroup
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:        libcgroup.keyring
Source3:        sysconfig.cgred
Source4:        cgrules.service
Source5:        cgconfig.service
Source6:        %{name}-rpmlintrc
Source7:        system-group-cgroup.conf
Source99:       baselibs.conf
Patch0:         cgroup-directory.patch
Patch1:         Syntax-fixes-for-man-pages.patch
Patch2:         pam_cgroup-Revert-broken-cache-usage.patch
Patch3:         template-doc.patch
Patch4:         oldfashion_init.patch
Patch5:         groups.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  permissions
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(pam)
BuildRequires:  pkgconfig(pkgconf)
BuildRequires:  pkgconfig(pkg-config)
BuildRequires:  sysuser-tools
%if ! %{defined _pam_moduledir}
%define _pam_moduledir /%{_lib}/security
%endif
%define add_optflags(a:f:t:p:w:W:d:g:O:A:C:D:E:H:i:M:n:P:U:u:l:s:X:B:I:L:b:V:m:x:c:S:E:o:v:) \
%global optflags %{optflags} %{**}

%description
Control groups infrastructure. The tools and library help manipulate, control,
administrate and monitor control groups and the associated controllers.

%package -n %{lname}
Summary:        Control groups management library
%description -n %{lname}

The shared library libcgroup 3.1.0 its self.

%package devel
Summary:        Control groups management tools devel package
Requires:       %{lname} = %{version}-%{release}

%description devel
This package contains the headers needed to build against
the libcgroup library in its ABI version 3 form.

%package tools
Summary:        Control groups management tools
# Added for openSUSE 12.3 to aid the solver.
Provides:       libcgroup1:%{_bindir}/cgexec
Provides:       group(cgred)
Requires(pre):  permissions
Recommends:     %{name}-pam
%sysusers_requires

%description tools
NOTE - this release is not guaranteed to be backward compatible with previous releases!

Libcgroup v3.1.0 adds systemd support to the libcgroup library.  Users can now create
systemd scopes via the libcgroup C APIs, command line tools, and (experimental) Python
bindings.  These scopes can be "delegated" (or not), which is systemd parlance for a
cgroup hierarchy that is being managed by another entity.  Systemd will not modify
settings or processes within a delegated hierarchy.

Note that libcgroup v3.1.0 is still capable of modifying cgroups and processes anywhere
in the cgroup hierarchy, including the root cgroup and its children (which are owned
by systemd).  Modifying cgroups and processes owned by systemd is a violation of the
cgroup single-writer rule, and systemd reserves the right to undo any changes made by
other processes.  The libcgroup team strongly discourages modifying systemd-managed
cgroups - especially on production systems - but it can be useful during prototyping
and on experimental systems.

The initial release of the cgroups implementation was in Linux 2.6.24.  Over time,
various cgroup controllers have been added to  allow  the  management  of  various
types of resources.  However, the development of these controllers was largely
uncoordinated, with the result that many inconsistencies arose between controllers and
management of the cgroup hierarchies became rather complex.

%package pam
Summary:        A Pluggable Authentication Module for libcgroup
Provides:       libcgroup-tools:%{_pam_moduledir}/pam_cgroup.so
Requires:       pam

%description pam
Linux-PAM module, which allows administrators to classify the user's login
processes to pre-configured control group.

%prep
%setup -q
%patch -P0 -p1
%patch -P1 -p1
%patch -P2 -p1
%patch -P3 -p1
%patch -P4
%patch -P5

%build
%add_optflags -D_GNU_SOURCE
%configure \
    --disable-silent-rules \
    --enable-cgred-socket=/run/cgred.socket \
    --enable-opaque-hierarchy="name=systemd" \
    --enable-pam-module-dir=%_pam_moduledir
%make_build

%install
%make_install DESTDIR=%{buildroot}
%sysusers_generate_pre %{S:7} cgred system-group-cgroup.conf
chmod u-s %{buildroot}%{_bindir}/cgexec
mkdir -p %{buildroot}%{_datadir}/permissions/permissions.d
mkdir -p %{buildroot}%{_sysconfdir}/cgconfig.d
mkdir -p %{buildroot}%{_sysusersdir}
pushd samples/config/
    install -m 644 cgconfig.conf     %{buildroot}%{_sysconfdir}
    install -m 644 cgrules.conf      %{buildroot}%{_sysconfdir}
    install -m 644 cgsnapshot_*.conf %{buildroot}%{_sysconfdir}
popd
mkdir -p %{buildroot}%{_unitdir}
    install -m 644 %{S:4} %{buildroot}%{_unitdir}/
    install -m 644 %{S:5} %{buildroot}%{_unitdir}/
    install -m 644 %{S:7} %{buildroot}%{_sysusersdir}/
find %{buildroot} -type f -a \( -name "*.la" -o -name "*.a" \) -delete -print
chmod u-s %{buildroot}/%{_bindir}/cgexec

(cat > %{buildroot}%{_datadir}/permissions/permissions.d/libcgroup)<<-'EOF'
	%{_bindir}/cgexec			root:cgred	2755
EOF

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%preun tools
%service_del_preun cgconfig.service
%service_del_preun cgrules.service

%postun tools
%service_del_postun cgconfig.service
%service_del_postun cgrules.service

%pre tools -f cgred.pre
%service_add_pre cgconfig.service
%service_add_pre cgrules.service

%post tools
%service_add_post cgconfig.service
%service_add_post cgrules.service
%set_permissions %{_bindir}/cgexec

%verifyscript tools
%verify_permissions -e %{_bindir}/cgexec

%files -n %{lname}
%license COPYING
%{_libdir}/libcgroup.so.*

%files tools
%license COPYING
%doc README
%doc README_daemon
%doc README_systemd
%config %{_sysconfdir}/*.conf
%dir %{_sysconfdir}/cgconfig.d
%dir %{_datadir}/permissions/permissions.d/
%{_datadir}/permissions/permissions.d/libcgroup
%{_unitdir}/*.service
%{_bindir}/cg[^e]*
%attr(2755,root,cgred) %{_bindir}/cgexec
%{_sbindir}/cg*
%{_bindir}/ls*
%{_bindir}/libcgroup_systemd_idle_thread
%{_mandir}/man[158]/*
%{_sysusersdir}/system-group-cgroup.conf

%files pam
%license COPYING
%{_pam_moduledir}/pam_cgroup.so

%files devel
%defattr(-,root,root)
%{_libdir}/libcgroup.so
%{_includedir}/libcgroup.h
%dir %{_includedir}/libcgroup
%{_includedir}/libcgroup/*.h
%{_libdir}/pkgconfig/libcgroup.pc

%changelog
* Wed Oct  2 2024 Dr. Werner Fink <werner@suse.de>
- Clean up package
  * Make systemd unit files work
  * Set socket path and socket group
  * Create group cgred
  * Use permission build/install api
* Tue Oct  1 2024 Dr. Werner Fink <werner@suse.de>
- Update to libcgroup-3.1.0
  NOTE - this release is not guaranteed to be backward compatible
  with previous releases!  There has been many changes!
  * Libcgroup v3.1.0 adds systemd support to the libcgroup library.
- Add cgrules.service and cgconfig.service below examples in
  package documentation of libcgroup-tools
- Adopt baselibs.conf to libcgroup3
- Split off a separate libcgroup-pam package
- Drop obsolete patches
  * cgconfig-Do-not-overwrite-defaultcgroup-configuratio.patch
  * do-not-version-pam-module.patch
  * initd_cgconfig.patch
  * initd_cgred.patch
- Add patches
  * Syntax-fixes-for-man-pages.patch
  * cgroup-directory.patch
  * oldfashion_init.patch
  * pam_cgroup-Revert-broken-cache-usage.patch
  * template-doc.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Jan 14 2015 tcech@suse.cz
- add Require for post install scriptlets (bnc#912531)
* Wed Jan 14 2015 mhocko@suse.de
- cgconfig-Do-not-overwrite-defaultcgroup-configuratio.patch - cgconfig:
  Do not overwrite defaultcgroup configuration (bnc#912487)
* Tue Jan 13 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Version bump to 0.41 - no changelog
- Add fillup/insserv prereqs bnc#912531
* Fri Jan 10 2014 mhocko@suse.com
- package upgraded from 0.37 to 0.41.rc1
- libcgroup-man_pages.patch: removed because obsoleted by 41b1e43155831
- initd_cgconfig-read-correctly-defaultcgroup.patch: removed because
  obsoleted by 9659403b713f9
* Thu May  2 2013 mhocko@suse.cz
- do-not-version-pam-module.patch: fix an invalid link to pam_cgroup.so.0.0.0
  and do not build cgroup pam module as a versioned shared object (bnc#817533)
* Tue Nov 27 2012 jengelh@inai.de
- Remove redundant/obsolete sections from specfile
- Follow shlib packaging guidelines; libcgroup1 ought to only have
  the library, move the rest into libcgroup-tools.
* Thu Nov 22 2012 mhocko@suse.cz
- initd_cgconfig-read-correctly-defaultcgroup.patch: fix defaultcgroup
  detection (bnc#790934)
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Oct 31 2011 jslaby@suse.de
- fix rpmlint warnings
* Wed Aug 31 2011 jslaby@suse.de
- don't use /var/lock/subsys/ (bnc#714631)
* Fri Jun 24 2011 jslaby@suse.de
- kill _service
* Wed May 11 2011 pth@suse.de
- Enhance the man pages.
* Thu Mar  3 2011 jslaby@suse.de
- update to 0.37.1
  - get rid of the local patches
  - fix buffer overflow (bnc#675506, CVE-2011-1006)
  - verify the sender of netlink messages (bnc#675048, CVE-2011-1022)
  - check length of netlink addresses (CVE-2011-1022)
  - improve handling of out-of-memory.
  - --sticky option works for setuid/setgid
* Wed Jan 12 2011 jslaby@suse.de
- sync cgconfig and cgred init.d scripts with upstream
- man pages fixes
* Tue Jan  4 2011 jslaby@suse.de
- update cgconfig and cgred init.d scripts
- fix segfault in cgconfigparser
* Mon Dec 20 2010 jslaby@suse.de
- update to 0.37
  - init scripts fixes
  - add new tools (scripts need not to do much work)
  - fixes in what tools and scripts return
  - many memory leaks fixed
  - other small fixes
* Mon Jul  5 2010 jslaby@suse.de
- update to 0.36.2 final
* Fri Jun  4 2010 kay.sievers@novell.com
- update to 0.36.2.rc
  - install pkg-config file
  - do not call exit() on error
- drop all patches which are upstream now or no longer needed
- install library in the rootfs, not in /usr
- enable verbose build
* Fri Feb  5 2010 jslaby@suse.de
- really fail to start (forgotten %%patch3)
* Thu Feb  4 2010 jslaby@suse.de
- fail to start when a parsing error occurs (bnc#576932)
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Aug 18 2009 jslaby@suse.de
- update init scripts. cgred moved to /usr/sbin/
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Mon May  4 2009 jslaby@suse.de
- update to 0.33
- refresh patches and make them -p1
- add pam module and manpages
* Fri Jan  2 2009 jslaby@suse.de
- Update to 0.32.2
- Fix devel package group (to Development/Libraries)
- Fix cgred init script
- Update cgconfig init script to create a default cgroup (bnc#458611)
* Wed Nov  5 2008 jslaby@suse.cz
- Update to 0.32.1
- Add init.d scripts configuration samples.
* Mon Oct 20 2008 schwab@suse.de
- Fix invalid use of sigaction.
* Wed Oct 15 2008 kukuk@suse.de
- Fix typo
* Tue Oct 14 2008 kukuk@suse.de
- Fix name of devel package
* Wed Oct  1 2008 jslaby@suse.cz
- initial package
